#ifndef _state_h_
#define _state_h_

/* coordinates structure */
struct coordinates {
	int x, y;
};

struct astime_state {
	long int update_interval; /* interval (sec) to update the dial */
	unsigned short int draw_seconds;
	unsigned short int draw_date;
	unsigned short int draw_ampm;
	struct coordinates total_size;
	short int shift;
	char bgcolor[50];
	char fgcolor[50];
	char seccolor[50];
	char mincolor[50];
	char hourcolor[50];
	char daycolor[50];
	char datecolor[50];
};

#endif

